@@ -357,7 +357,7 @@ read_number (ParserState *state)
 			{
 				leading_zero = TRUE;
 			}
-			if (got_digit && leading_zero)
+			else if (leading_zero && !is_float)
 			{
 				PyErr_Format (LeadingZeroError, "Invalid leading zero");
 				return NULL;
@@ -373,7 +373,7 @@ read_number (ParserState *state)
 		case '7':
 		case '8':
 		case '9':
-			if (leading_zero)
+			if (leading_zero && !is_float)
 			{
 				PyErr_Format (LeadingZeroError, "Invalid leading zero");
 				return NULL;
@@ -480,6 +480,7 @@ read_array_impl (PyObject *list, ParserState *state)
 		
 		else
 		{
+			PyObject *value;
 			if (array_state == ARRAY_GOT_VALUE)
 			{
 				PyErr_Format (ReadError,
@@ -489,7 +490,6 @@ read_array_impl (PyObject *list, ParserState *state)
 				return FALSE;
 			}
 			
-			PyObject *value;
 			if ((value = json_read (state)))
 			{
 				int result = PyList_Append (list, value);
